referrerpolicy=no-referrer-when-downgrade

multi_account_id

Function multi_account_id 

pub fn multi_account_id<AccountId: Encode + Decode>(
    who: &[AccountId],
    threshold: u16,
) -> AccountId
Derive a multi-account ID from the sorted list of accounts and the threshold.

This is used to compute the inheritor for migrated recovery configs - the inheritor will be the multisig account that the friends can control together.

NOTE: who must be sorted. If it is not, then you’ll get the wrong answer.