referrerpolicy=no-referrer-when-downgrade

ActiveRecoveries

Type Alias ActiveRecoveries 

pub type ActiveRecoveries<T> = StorageDoubleMap<ActiveRecoveries_Storage_Instance<T>, Twox64Concat, <T as Config>::AccountId, Twox64Concat, <T as Config>::AccountId, ActiveRecovery<BlockNumberFromProviderOf<T>, BalanceOf<T>, FriendsOf<T>>>;
Old storage: Active recovery attempts.

First account is the account to be recovered, and the second account is the user trying to recover the account.

Aliased Type

pub struct ActiveRecoveries<T>(/* private fields */);